summaryrefslogtreecommitdiff
path: root/xstatic/pkg/jquery_ui/data/ui/jquery.ui.slider.js
diff options
context:
space:
mode:
Diffstat (limited to 'xstatic/pkg/jquery_ui/data/ui/jquery.ui.slider.js')
-rw-r--r--xstatic/pkg/jquery_ui/data/ui/jquery.ui.slider.js8
1 files changed, 4 insertions, 4 deletions
diff --git a/xstatic/pkg/jquery_ui/data/ui/jquery.ui.slider.js b/xstatic/pkg/jquery_ui/data/ui/jquery.ui.slider.js
index 23a56cc..c554e78 100644
--- a/xstatic/pkg/jquery_ui/data/ui/jquery.ui.slider.js
+++ b/xstatic/pkg/jquery_ui/data/ui/jquery.ui.slider.js
@@ -1,7 +1,7 @@
/*
* jQuery UI Slider 1.8.18
*
- * Copyright 2011, AUTHORS.txt (http://jqueryui.com/about)
+ * Copyright 2012, AUTHORS.txt (http://jqueryui.com/about)
* Dual licensed under the MIT or GPL Version 2 licenses.
* http://jquery.org/license
*
@@ -656,7 +656,7 @@ $.widget( "ui.slider", $.ui.mouse, {
});
$.extend( $.ui.slider, {
- version: "1.8.18"
+ version: "1.8.24"
});
}(jQuery));
@@ -1,7 +1,7 @@
-/*
- * jQuery UI Slider 1.8.18
+/*!
+ * jQuery UI Slider 1.8.24
*